@@ -5,7 +5,7 @@ tar -vzxf carna.tgz
 cd "Carna-$VERSION_CARNA"
 mkdir -p build/make_release
 cd "$$ROOT_DIR/Carna-$VERSION_CARNA/build/make_release"
-cmake -DCMAKE_BUILD_TYPE=Release -DBUILD_DOC=OFF -DBUILD_TEST=ON -DBUILD_DEMO=OFF -DCMAKE_INSTALL_PREFIX=$$PREFIX -DCMAKE_PREFIX_PATH=$$PREFIX -DBUILD_EGL=ON ../..
+cmake -DCMAKE_BUILD_TYPE=Release -DBUILD_DOC=OFF -DBUILD_TEST=OFF -DBUILD_DEMO=OFF -DCMAKE_INSTALL_PREFIX=$$PREFIX -DCMAKE_PREFIX_PATH=$$PREFIX -DBUILD_EGL=ON ../..
 make VERBOSE=1
 make install
 
